Internal function returning the vector of all valid algorithm identifiers
supported by the OptimalBinningWoE package. Used for validation and
parameter definition.
Usage
.valid_algorithms()
Arguments
Value
A character vector of valid algorithm names including "auto".