Learn R Programming

OptimalBinningWoE (version 1.0.8)

bake.step_obwoe: Apply the Optimal Binning Transformation

Description

Applies the learned binning and WoE transformation to new data. This method is called by bake and should not be invoked directly.

Usage

# S3 method for step_obwoe
bake(object, new_data, ...)

Value

A tibble with transformed columns according to the output

parameter.

Arguments

object

A trained step_obwoe object.

new_data

A tibble or data frame to transform.

...

Additional arguments (currently unused).