Learn R Programming

OptimalBinningWoE (version 1.0.8)

print.obwoe: Print Method for obwoe Objects

Description

Displays a concise summary of optimal binning results, including the number of successfully processed features and top predictors ranked by Information Value.

Usage

# S3 method for obwoe
print(x, ...)

Value

Invisibly returns x.

Arguments

x

An object of class "obwoe".

...

Additional arguments (currently ignored).

See Also

summary.obwoe for detailed statistics, plot.obwoe for visualization.