The minimum number of bins constrains the algorithm to create at least
this many bins. Setting min_bins = 2 allows maximum flexibility,
while higher values ensure more granular discretization.
For credit scoring applications, min_bins is typically set between
2 and 4 to avoid forcing artificial splits on weakly predictive variables.